@@ -21,7 +21,7 @@ from function_scheduling_distributed_framework.consumers.sqlachemy_consumer impo
 def get_consumer(queue_name, *, consuming_function: Callable = None, function_timeout=0, threads_num=50,
                  concurrent_num=50, specify_threadpool=None, concurrent_mode=1,
                  max_retry_times=3, log_level=10, is_print_detail_exception=True, msg_schedule_time_intercal=0.0,
-                 qps=0, msg_expire_senconds=0,
+                 qps: float = 0, msg_expire_senconds=0, is_using_distributed_frequency_control=False,
                  logger_prefix='', create_logger_file=True, do_task_filtering=False, task_filtering_expire_seconds=0,
                  is_consuming_function_use_multi_params=True,
                  is_do_not_run_by_specify_time_effect=False, do_not_run_by_specify_time=('10:00:00', '22:00:00'),
@@ -47,6 +47,8 @@ def get_consumer(queue_name, *, consuming_function: Callable = None, function_ti
     :param msg_schedule_time_intercal:消息调度的时间间隔，用于控频的关键。
     :param qps:指定1秒内的函数执行次数，qps会覆盖msg_schedule_time_intercal，以后废弃msg_schedule_time_intercal这个参数。
     :param msg_expire_senconds:消息过期时间，为0永不过期，为10则代表，10秒之前发布的任务如果现在才轮到消费则丢弃任务。
+     :param is_using_distributed_frequency_control: 是否使用分布式空频（依赖redis计数），默认只对当前实例化的消费者空频有效。假如实例化了2个qps为10的使用同一队列名的消费者，
+               并且都启动，则每秒运行次数会达到20。如果使用分布式空频则所有消费者加起来的总运行次数是10。
     :param logger_prefix: 日志前缀，可使不同的消费者生成不同的日志
     :param create_logger_file : 是否创建文件日志
     :param do_task_filtering :是否执行基于函数参数的任务过滤
@@ -67,27 +69,19 @@ def get_consumer(queue_name, *, consuming_function: Callable = None, function_ti
     """
     all_kwargs = copy.copy(locals())
     all_kwargs.pop('broker_kind')
-    if broker_kind == 0:
-        return RabbitmqConsumer(**all_kwargs)
-    elif broker_kind == 1:
-        return RabbitmqConsumerRabbitpy(**all_kwargs)
-    elif broker_kind == 2:
-        return RedisConsumer(**all_kwargs)
-    elif broker_kind == 3:
-        return LocalPythonQueueConsumer(**all_kwargs)
-    elif broker_kind == 4:
-        return RabbitmqConsumerAmqpStorm(**all_kwargs)
-    elif broker_kind == 5:
-        return MongoMqConsumer(**all_kwargs)
-    elif broker_kind == 6:
-        return PersistQueueConsumer(**all_kwargs)
-    elif broker_kind == 7:
-        return NsqConsumer(**all_kwargs)
-    elif broker_kind == 8:
-        return KafkaConsumer(**all_kwargs)
-    elif broker_kind == 9:
-        return RedisConsumerAckAble(**all_kwargs)
-    elif broker_kind == 10:
-        return SqlachemyConsumer(**all_kwargs)
-    else:
+    broker_kind__consumer_type_map = {
+        0: RabbitmqConsumer,
+        1: RabbitmqConsumerRabbitpy,
+        2: RedisConsumer,
+        3: LocalPythonQueueConsumer,
+        4: RabbitmqConsumerAmqpStorm,
+        5: MongoMqConsumer,
+        6: PersistQueueConsumer,
+        7: NsqConsumer,
+        8: KafkaConsumer,
+        9: RedisConsumerAckAble,
+        10: SqlachemyConsumer,
+    }
+    if broker_kind not in broker_kind__consumer_type_map:
         raise ValueError('设置的中间件种类数字不正确')
+    return broker_kind__consumer_type_map[broker_kind](**all_kwargs)
